==> lsp-plugins_1.2.14.orig.tar.gz: lsp-plugins/modules/lsp-plugin-fw/src/test/mtest/validator.cpp <==
/*
 * Copyright (C) 2021 Linux Studio Plugins Project <https://lsp-plug.in/>
 *           (C) 2021 Vladimir Sadovnikov <sadko4u@gmail.com>
 *
 * This file is part of lsp-plugin-fw
 * Created on: 9 янв. 2023 г.
 *
 * lsp-plugin-fw is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * lsp-plugin-fw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with lsp-plugin-fw. If not, see <https://www.gnu.org/licenses/>.
 */

#include <lsp-plug.in/common/status.h>
#include <lsp-plug.in/io/Path.h>
#include <lsp-plug.in/plug-fw/util/validator/validator.h>
#include <lsp-plug.in/runtime/system.h>
#include <lsp-plug.in/test-fw/mtest.h>


MTEST_BEGIN("", validator)

    MTEST_MAIN
    {
        // Pass the path to resource directory
    #ifdef LSP_IDE_DEBUG
        io::Path resdir;
        resdir.set(tempdir(), "resources");
        system::set_env_var("LSP_RESOURCE_PATH", resdir.as_string());
    #endif /* LSP_IDE_DEBUG */

        const char *data[]=
        {
            "validator",
        };

        // Pass the path to resource directory
        MTEST_ASSERT(lsp::validator::main(sizeof(data)/sizeof(const char *), data) == STATUS_OK);
    }

MTEST_END

==> lsp-plugins_1.2.26.orig.tar.gz: lsp-plugins/modules/lsp-plugin-fw/src/test/mtest/validator.cpp <==
/*
 * Copyright (C) 2021 Linux Studio Plugins Project <https://lsp-plug.in/>
 *           (C) 2021 Vladimir Sadovnikov <sadko4u@gmail.com>
 *
 * This file is part of lsp-plugin-fw
 * Created on: 9 янв. 2023 г.
 *
 * lsp-plugin-fw is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * lsp-plugin-fw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with lsp-plugin-fw. If not, see <https://www.gnu.org/licenses/>.
 */

#include <lsp-plug.in/common/status.h>
#include <lsp-plug.in/io/Path.h>
#include <lsp-plug.in/plug-fw/const.h>
#include <lsp-plug.in/plug-fw/util/validator/validator.h>
#include <lsp-plug.in/runtime/system.h>
#include <lsp-plug.in/test-fw/mtest.h>


MTEST_BEGIN("", validator)

    MTEST_MAIN
    {
        // Pass the path to resource directory
    #ifdef LSP_NO_BUILTIN_RESOURCES
        io::Path resdir;
        resdir.set(tempdir(), "resources");
        system::set_env_var(LSP_RESOURCE_PATH_VAR, resdir.as_string());
    #endif /* LSP_NO_BUILTIN_RESOURCES */

        const char *data[]=
        {
            "validator",
        };

        // Pass the path to resource directory
        MTEST_ASSERT(lsp::validator::main(sizeof(data)/sizeof(const char *), data) == STATUS_OK);
    }

MTEST_END
